# samesite-checker

Check if SameSite=None is compatible with user agents.
[https://www.chromium.org/updates/same-site/incompatible-clients](https://www.chromium.org/updates/same-site/incompatible-clients)